@@ -31,8 +31,9 @@ Opera
    <fr_BE>Navigateur Opera (32 bit en beta uniquement)</fr_BE>
    <fr>Navigateur Opera (32 bit en beta uniquement)</fr>
    <gl_ES>Navegador web Opera (32 bit is beta-only)</gl_ES>
+   <gu>Opera browser (32 bit is beta-only)</gu>
    <he_IL>Opera browser (32 bit is beta-only)</he_IL>
-   <hi>Opera browser (32 bit is beta-only)</hi>
+   <hi>ओपेरा ब्राउज़र (32 बिट केवल बीटा है)</hi>
    <hr>Opera browser (32 bit is beta-only)</hr>
    <hu>Opera browser (32 bit is beta-only)</hu>
    <id>Opera browser (32 bit is beta-only)</id>
@@ -41,6 +42,7 @@ Opera
    <ja>Opera ブラウザー (32 bit 版は beta のみ)</ja>
    <kk>Opera browser (32 bit is beta-only)</kk>
    <ko>Opera browser (32 bit is beta-only)</ko>
+   <ku>Opera browser (32 bit is beta-only)</ku>
    <lt>Opera naršyklė (32 bitų yra tik beta versija)</lt>
    <mk>Opera browser (32 bit is beta-only)</mk>
    <mr>Opera browser (32 bit is beta-only)</mr>
@@ -48,6 +50,7 @@ Opera
    <nb>Nettleseren Opera (32 bit er kun beta)</nb>
    <nl_BE>Opera browser (32 bit is beta-only)</nl_BE>
    <nl>Opera browser (32 bit is enkel-beta)</nl>
+   <or>Opera browser (32 bit is beta-only)</or>
    <pl>przeglądarka Opera (wersja 32-bitowa tylko w wersji beta)</pl>
    <pt_BR>Opera - Versão beta de 32 bits do navegador de internet</pt_BR>
    <pt>Navegador web Opera (32 bit is beta-only)</pt>
@@ -55,7 +58,8 @@ Opera
    <ru>Браузер Opera (32 bit бета-версия)</ru>
    <sk>Opera browser (32 bit is beta-only)</sk>
    <sl>Opera brskalnik (32 bitni je zgolj beta)</sl>
-   <sq>Opera browser (32 bit is beta-only)</sq>
+   <so>Opera browser (32 bit is beta-only)</so>
+   <sq>Shfletuesi Opera (32 bitshi është vetëm version beta)</sq>
    <sr>Opera browser (32 bit is beta-only)</sr>
    <sv>Opera webbläsare (32 bit är enbart i beta)</sv>
    <th>เบราว์เซอร์ Opera (32 bit เป็นเบต้าเท่านั้น)</th>
